@@ -2,9 +2,11 @@ import logging
 import logging.config
 import os
 import sys
+import presalytics
 
 default_log_path = os.getcwd() + os.path.sep + 'presalytics.log'
 
+USE_LOGGER = False
 
 def configure_logger(log_path=default_log_path, log_level='DEBUG', file_logger=True):
     logging.config.dictConfig({
@@ -37,18 +39,22 @@ def configure_logger(log_path=default_log_path, log_level='DEBUG', file_logger=T
         log_file = os.path.join(log_dir, 'presalytics.log')
         file_handler = logging.FileHandler(log_file)
         logger.addHandler(file_handler)
-
+    
+    USE_LOGGER = file_logger
 
 def handle_exception(exc_type, exc_value, exc_traceback):
     """ Catches unhandled exceptions for logger """
     try:
         logger = logging.getLogger('presalytics.exception_hook')
-        logger.error("--------------------------")
-        logger.error("UNHANDLED EXCEPTION: FATAL")
-        logger.error(msg="--------------------------", exc_info=(exc_type, exc_value, exc_traceback,))
-        logger.error("--------------------------")
-        logger.error("UNHANDLED EXCEPTION: FATAL")
-        logger.error("--------------------------")
+        if USE_LOGGER:
+            logger.error("--------------------------")
+            logger.error("UNHANDLED EXCEPTION: FATAL")
+            logger.error(msg="--------------------------", exc_info=(exc_type, exc_value, exc_traceback,))
+            logger.error("--------------------------")
+            logger.error("UNHANDLED EXCEPTION: FATAL")
+            logger.error("--------------------------")
+        else:
+            logger.error(msg="An unhandled exception occured.", exc_info=(exc_type, exc_value, exc_traceback,))
     except Exception:
         pass
     return
