@@ -94,8 +94,25 @@ class Revealer(presalytics.story.components.Renderer):
         logger.info("Revealer initilized.")
 
     def _make_base(self):
-        base = lxml.etree.Element("div", attrib={"class": "reveal"})
+        base = lxml.etree.Element("div", attrib={
+            "class": "reveal",
+        })
         lxml.etree.SubElement(base, "div", attrib={"class": "slides"})
+        try:
+            client = self.get_client()
+            website_token = client.token_util.token["access_token"]
+            client.exchange_token(website_token, audience='story-ui')
+            base.attrib['data-jwt'] = client.token_util.token["access_token"]
+            base.attrib['data-jwt-refresh'] = client.token_util.token["refresh_token"]
+            base.attrib['data-story-target'] = client.story.api_client.configuration.host
+        except Exception as ex:
+            logger.exception(ex, "Could not obtain access token from revealer component.")
+
+        try:
+            story_id = self.story_outline.story_id
+            base.attrib['data-story-id'] = story_id
+        except Exception:
+            logger.info("Revealer could not extract story_id from outline.")
         return base
     
     def get_meta_tags(self):
